# package_name

Description. 
The package tradutor is used to:
	- Translate short texts from English to Portuguese
	- Translate short texts from Portuguese to English

Descrição:
O pacote tradutor é utilizado para:
	- Traduzir um texto curto do Inglês para o Português
	- Traduzir um texto curto do Português para o Inglês

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install tradutor

```bash
pip install tradutor
```

## Usage

```python
from tradutor import tradutor_pten, translate_enpt
tradutor_pten.pt_en('texto a ser traduzido')
translate_enpt.en_pt('What do you want to translate into Portuguese?')
```

## Author
Paulo Ricardo Diniz

## License
[MIT](https://choosealicense.com/licenses/mit/)
